@@ -40,70 +40,70 @@ ParsingHelper *ParsingHelper::instance()
 ParsingHelper::ParsingHelper()
 {
     // Initialize Existing months
-    mapMonths[QLatin1String("Jan")] = 1;
-    mapMonths[QLatin1String("Feb")] = 2;
-    mapMonths[QLatin1String("Mar")] = 3;
-    mapMonths[QLatin1String("Apr")] = 4;
-    mapMonths[QLatin1String("May")] = 5;
-    mapMonths[QLatin1String("Jun")] = 6;
-    mapMonths[QLatin1String("Jul")] = 7;
-    mapMonths[QLatin1String("Aug")] = 8;
-    mapMonths[QLatin1String("Sep")] = 9;
-    mapMonths[QLatin1String("Oct")] = 10;
-    mapMonths[QLatin1String("Nov")] = 11;
-    mapMonths[QLatin1String("Dec")] = 12;
+    mapMonths[QStringLiteral("Jan")] = 1;
+    mapMonths[QStringLiteral("Feb")] = 2;
+    mapMonths[QStringLiteral("Mar")] = 3;
+    mapMonths[QStringLiteral("Apr")] = 4;
+    mapMonths[QStringLiteral("May")] = 5;
+    mapMonths[QStringLiteral("Jun")] = 6;
+    mapMonths[QStringLiteral("Jul")] = 7;
+    mapMonths[QStringLiteral("Aug")] = 8;
+    mapMonths[QStringLiteral("Sep")] = 9;
+    mapMonths[QStringLiteral("Oct")] = 10;
+    mapMonths[QStringLiteral("Nov")] = 11;
+    mapMonths[QStringLiteral("Dec")] = 12;
 
     // Initialize HTTP Responses
     // 1xx Responses
-    mapHTTPResponse[QLatin1String("100")] = QLatin1String("Continue");
-    mapHTTPResponse[QLatin1String("101")] = QLatin1String("Switching Protocols");
+    mapHTTPResponse[QStringLiteral("100")] = QLatin1String("Continue");
+    mapHTTPResponse[QStringLiteral("101")] = QLatin1String("Switching Protocols");
 
     // 2xx Responses
-    mapHTTPResponse[QLatin1String("200")] = QLatin1String("OK");
-    mapHTTPResponse[QLatin1String("201")] = QLatin1String("Created");
-    mapHTTPResponse[QLatin1String("202")] = QLatin1String("Accepted");
-    mapHTTPResponse[QLatin1String("203")] = QLatin1String("Non-Authoritative Information");
-    mapHTTPResponse[QLatin1String("204")] = QLatin1String("No Content");
-    mapHTTPResponse[QLatin1String("205")] = QLatin1String("Reset Content");
-    mapHTTPResponse[QLatin1String("206")] = QLatin1String("Partial Content");
+    mapHTTPResponse[QStringLiteral("200")] = QLatin1String("OK");
+    mapHTTPResponse[QStringLiteral("201")] = QLatin1String("Created");
+    mapHTTPResponse[QStringLiteral("202")] = QLatin1String("Accepted");
+    mapHTTPResponse[QStringLiteral("203")] = QLatin1String("Non-Authoritative Information");
+    mapHTTPResponse[QStringLiteral("204")] = QLatin1String("No Content");
+    mapHTTPResponse[QStringLiteral("205")] = QLatin1String("Reset Content");
+    mapHTTPResponse[QStringLiteral("206")] = QLatin1String("Partial Content");
 
     // 3xx Responses
-    mapHTTPResponse[QLatin1String("300")] = QLatin1String("OK");
-    mapHTTPResponse[QLatin1String("301")] = QLatin1String("Moved Permanently");
-    mapHTTPResponse[QLatin1String("302")] = QLatin1String("Found");
-    mapHTTPResponse[QLatin1String("303")] = QLatin1String("See Other");
-    mapHTTPResponse[QLatin1String("304")] = QLatin1String("Not Modified");
-    mapHTTPResponse[QLatin1String("305")] = QLatin1String("Use Proxy");
-    mapHTTPResponse[QLatin1String("306")] = QLatin1String("(Unused)");
-    mapHTTPResponse[QLatin1String("307")] = QLatin1String("Temporary Redirect");
+    mapHTTPResponse[QStringLiteral("300")] = QLatin1String("OK");
+    mapHTTPResponse[QStringLiteral("301")] = QLatin1String("Moved Permanently");
+    mapHTTPResponse[QStringLiteral("302")] = QLatin1String("Found");
+    mapHTTPResponse[QStringLiteral("303")] = QLatin1String("See Other");
+    mapHTTPResponse[QStringLiteral("304")] = QLatin1String("Not Modified");
+    mapHTTPResponse[QStringLiteral("305")] = QLatin1String("Use Proxy");
+    mapHTTPResponse[QStringLiteral("306")] = QLatin1String("(Unused)");
+    mapHTTPResponse[QStringLiteral("307")] = QLatin1String("Temporary Redirect");
 
     // 4xx Responses
-    mapHTTPResponse[QLatin1String("400")] = QLatin1String("Bad Request");
-    mapHTTPResponse[QLatin1String("401")] = QLatin1String("Unauthorized");
-    mapHTTPResponse[QLatin1String("402")] = QLatin1String("Payment Required");
-    mapHTTPResponse[QLatin1String("403")] = QLatin1String("Forbidden");
-    mapHTTPResponse[QLatin1String("404")] = QLatin1String("Not Found");
-    mapHTTPResponse[QLatin1String("405")] = QLatin1String("Method Not Allowed");
-    mapHTTPResponse[QLatin1String("406")] = QLatin1String("Not Acceptable");
-    mapHTTPResponse[QLatin1String("407")] = QLatin1String("Proxy Authentication Required");
-    mapHTTPResponse[QLatin1String("408")] = QLatin1String("Request Timeout");
-    mapHTTPResponse[QLatin1String("409")] = QLatin1String("Conflict");
-    mapHTTPResponse[QLatin1String("410")] = QLatin1String("Gone");
-    mapHTTPResponse[QLatin1String("411")] = QLatin1String("Length Required");
-    mapHTTPResponse[QLatin1String("412")] = QLatin1String("Precondition Failed");
-    mapHTTPResponse[QLatin1String("413")] = QLatin1String("Request Entity Too Large");
-    mapHTTPResponse[QLatin1String("414")] = QLatin1String("Request-URI Too Long");
-    mapHTTPResponse[QLatin1String("415")] = QLatin1String("Unsupported Media Type");
-    mapHTTPResponse[QLatin1String("416")] = QLatin1String("Requested Range Not Satisfiable");
-    mapHTTPResponse[QLatin1String("417")] = QLatin1String("Expectation Failed");
+    mapHTTPResponse[QStringLiteral("400")] = QLatin1String("Bad Request");
+    mapHTTPResponse[QStringLiteral("401")] = QLatin1String("Unauthorized");
+    mapHTTPResponse[QStringLiteral("402")] = QLatin1String("Payment Required");
+    mapHTTPResponse[QStringLiteral("403")] = QLatin1String("Forbidden");
+    mapHTTPResponse[QStringLiteral("404")] = QLatin1String("Not Found");
+    mapHTTPResponse[QStringLiteral("405")] = QLatin1String("Method Not Allowed");
+    mapHTTPResponse[QStringLiteral("406")] = QLatin1String("Not Acceptable");
+    mapHTTPResponse[QStringLiteral("407")] = QLatin1String("Proxy Authentication Required");
+    mapHTTPResponse[QStringLiteral("408")] = QLatin1String("Request Timeout");
+    mapHTTPResponse[QStringLiteral("409")] = QLatin1String("Conflict");
+    mapHTTPResponse[QStringLiteral("410")] = QLatin1String("Gone");
+    mapHTTPResponse[QStringLiteral("411")] = QLatin1String("Length Required");
+    mapHTTPResponse[QStringLiteral("412")] = QLatin1String("Precondition Failed");
+    mapHTTPResponse[QStringLiteral("413")] = QLatin1String("Request Entity Too Large");
+    mapHTTPResponse[QStringLiteral("414")] = QLatin1String("Request-URI Too Long");
+    mapHTTPResponse[QStringLiteral("415")] = QLatin1String("Unsupported Media Type");
+    mapHTTPResponse[QStringLiteral("416")] = QLatin1String("Requested Range Not Satisfiable");
+    mapHTTPResponse[QStringLiteral("417")] = QLatin1String("Expectation Failed");
 
     // 5xx Responses
-    mapHTTPResponse[QLatin1String("500")] = QLatin1String("Internal Server Error");
-    mapHTTPResponse[QLatin1String("501")] = QLatin1String("Not Implemented");
-    mapHTTPResponse[QLatin1String("502")] = QLatin1String("Bad Gateway");
-    mapHTTPResponse[QLatin1String("503")] = QLatin1String("Service Unavailable");
-    mapHTTPResponse[QLatin1String("504")] = QLatin1String("Gateway Timeout");
-    mapHTTPResponse[QLatin1String("505")] = QLatin1String("HTTP Version Not Supported");
+    mapHTTPResponse[QStringLiteral("500")] = QLatin1String("Internal Server Error");
+    mapHTTPResponse[QStringLiteral("501")] = QLatin1String("Not Implemented");
+    mapHTTPResponse[QStringLiteral("502")] = QLatin1String("Bad Gateway");
+    mapHTTPResponse[QStringLiteral("503")] = QLatin1String("Service Unavailable");
+    mapHTTPResponse[QStringLiteral("504")] = QLatin1String("Gateway Timeout");
+    mapHTTPResponse[QStringLiteral("505")] = QLatin1String("HTTP Version Not Supported");
 }
 
 ParsingHelper::~ParsingHelper()
@@ -148,7 +148,7 @@ QDateTime ParsingHelper::parseSyslogDateTime(const QString &dateTime)
 
 QString ParsingHelper::syslogDateTimeRegexp()
 {
-    return QLatin1String("(\\S*[ ]+\\d* \\d*:\\d*:\\d* \\d*)");
+    return QStringLiteral("(\\S*[ ]+\\d* \\d*:\\d*:\\d* \\d*)");
 }
 
 int ParsingHelper::parseSyslogMonth(const QString &string)
